.. Dashport documentation master file, created by
   sphinx-quickstart on Sun Jun  5 15:53:17 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Dashport
========

`Dashport <https://github.com/numbertheory/dashport>`_ is a wrapper for Python's `curses <https://docs.python.org/3/library/curses.html>`_ library to enable developers to easily make curses-based applications.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   dashport
   colors
   strings
   layouts
   widgets

.. toctree::
   :maxdepth: 1
   :caption: Examples:

   examples/index
   examples/boilerplate
   examples/layouts
   examples/util
   examples/views
